@@ -158,9 +158,7 @@ void delete_pidfile(void) {
 	}
 }
 
-/* open and set termios settings for a single port, storing original settings */
-void setup_one_termios(gpointer data, gpointer ignore) {
-	machine *m = data;
+void open_one_logfile(machine *m) {
 	char *logname;
 
 	logname = alloca(strlen(logpath)+strlen(m->name)+6);
@@ -168,6 +166,13 @@ void setup_one_termios(gpointer data, gpointer ignore) {
 	m->log_fd = open(logname, O_RDWR|O_CREAT|O_APPEND, 0666);
 	if (m->log_fd < 0)
 		warn(strerror(errno), m);
+}
+
+/* open and set termios settings for a single port, storing original settings */
+void setup_one_termios(gpointer data, gpointer ignore) {
+	machine *m = data;
+
+	open_one_logfile(m);
 
 	m->dev_fd = open(m->devpath, O_RDONLY|O_NOCTTY);
 	if (m->dev_fd < 0) {
@@ -227,14 +232,9 @@ void cleanup_termios_and_exit(int signal) {
 
 void reopen_one_logfile(gpointer data, gpointer ignore) {
 	machine *m = data;
-	char *logname;
 
-	logname = alloca(strlen(logpath)+strlen(m->name)+2);
-	sprintf(logname, "%s/%s", logpath, m->name);
 	close(m->log_fd);
-	m->log_fd = open(logname, O_RDWR|O_CREAT|O_APPEND, 0666);
-	if (m->log_fd < 0)
-		warn(strerror(errno), m);
+	open_one_logfile(m);
 }
 
 void reopen_logfiles(int signo) {
@@ -296,8 +296,9 @@ machine *parse_argument (char c, machine *m) {
 			
 			/* read the config file line by line */
 			for (confline = conftext;
-			     confline = confnext, confline;
-			     confnext = strchr(confline, '\n')) {
+			     confline;
+			     confline = confnext) {
+				confnext = strchr(confline, '\n');
 				if (confnext) *confnext++ = '\0';
 
 				if (confline[0] == '#') continue;
